@@ -6,6 +6,6 @@ from django.test import TestCase
 import factory
 from faker import Faker
 
-from djaq import DjangoQuery as DQ, DQResult
+from djaq import DjaqQuery as DQ, DQResult
 
 from django.db.models import Q, Avg, Count, Min, Max, Sum, FloatField, F
